/// --------------------------------------------------------------------------------
/// region Description
/// **************************************************************************
/// Script file for GeckoR2 MiniTerm Scripting
/// **************************************************************************
/// Syntax:
/// --------------------------------------------------------------------------
/// Serial communication commands
/// "[code] {option1:[data1]} {option2:[data2]} {option3:[data3] {..."
///    Code syntax : sn? / control=1
///    Options (case insensitive)
///       "validation"   : Expected value (string comparison)
///       "validation<"  : Expected value (number comparison)
///       "validation="  : Expected value (number comparison)
///       "validation<=" : Expected value (number comparison)
///       "validation>=" : Expected value (number comparison)
///       "validation>"  : Expected value (number comparison)
///       "txrxwaitms"   : Delay between tx and rx
///       "variable"     : Store result into this variable (as string)
///       "continue"     : Continue after error (default: 0 / 1)
/// --------------------------------------------------------------------------
/// Logging commands
/// "!echo [comment]"          : Write comment into miniterm window
///                              Examples:
///                              !echo this is the value of variable x [variablex]
/// "!addtoreport [comment]"   : Write data with comment into report file
/// --------------------------------------------------------------------------
/// Workflow commands
/// "!wait [nnnn]"             : Wait for nnnn ms
/// "!goto [uniquelabel]"      : Jump to the line with the label "::[uniquelabel]"
/// --------------------------------------------------------------------------
/// Calculation commands
/// "!calculate {expression:...} {variable:...}
///    Code syntax : !calculate {expression:(2*3)-1/2} {variable:_calcresult}
///    Code syntax : !calculate {expression:[variable1]/15*[variable2]} {variable:_calcresult}
///    Options (case insensitive)
///       "expression"   : compute this expression (variables in form [variable])
///       "variable"     : Store result into this variable (as string)
///    Valid expressions see:
///    https://docs.microsoft.com/en-us/dotnet/api/system.data.datacolumn.expression?redirectedfrom=MSDN&view=netframework-4.8 {System_Data_DataColumn_Expression
/// --------------------------------------------------------------------------
/// Settings commands
/// "!parameter [key] [value]" : Change Gecko settings parameter
///    Supported keys:
///    Size                  : NumOf values for average/deviation (Integer value)
///    WriteToLogInS         : Log interval in seconds (Integer value)
///    ReadFromInstrumentInS : Read delay interval in seconds (Integer value)
///    ReadTimeLimitInS      : Allowed duration for one read loop (Integer value)
/// --------------------------------------------------------------------------
///
///
/// Short Cuts to collapse & expand :
/// To collapse/fold all blocks -> Alt + 0.
/// To expand/unfold all blocks -> Alt + Shift + 0.
/// To collapse current level   -> Ctrl + Alt + F.
/// To expand current level     -> Ctrl + Shift + Alt + F.
///
/// Colors: https://docs.microsoft.com/en-us/dotnet/api/system.windows.media.brushes?view=netframework-4.8
/// Decoration: https://docs.microsoft.com/en-us/dotnet/api/system.windows.textdecoration?view=netframework-4.8
/// DateTime format: https://www.c-sharpcorner.com/blogs/date-and-time-format-in-c-sharp-programming1
///
/// MessageBox-Button: https://docs.microsoft.com/en-us/dotnet/api/system.windows.forms.messageboxbuttons?view=netframework-4.8
/// MessageBox-Image: https://docs.microsoft.com/en-us/dotnet/api/system.windows.messageboximage?view=netframework-4.8
/// MessageBox-Result: https://docs.microsoft.com/en-us/dotnet/api/system.windows.messageboxresult?view=netframework-4.8
/// MessageBox-Options: https://docs.microsoft.com/en-us/dotnet/api/system.windows.forms.messageboxoptions?view=netframework-4.8
///
/// Echo-Controls: https://docs.microsoft.com/en-us/dotnet/api/system.windows.controls?view=netframework-4.8
/// endregion 
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: Selection
/// --------------------------------------------------------------------------------

/// Define-Variables
!setvariable {name:TRACE}{group:Application} {value:true}

!setvariable {name:PERSISTENCY} {value:.\variables.save}
!setvariable {name:ECHO_TITLE1} {value:{foreground:Green} {fontweight:Bold} {fontsize:24}} {group:group_preset_echo_format} {description:Preset - Echo format title1}
!setvariable {name:ECHO_TITLE2} {value:{foreground:Blue} {fontweight:Bold} {fontsize:18} {fontfamily:Arial} {spacesizebefore:18}} {group:group_preset_echo_format} {description:Preset - Echo format title2}
!setvariable {name:SELECTION_CHECKBOX} {value:{value:false} {group:group_example_selection} {extension:[true/false]} {control: CheckBox} {persistencypath:[PERSISTENCY]}} {group:group_preset_selection} {description:Preset - Selection checkbox}

/// Selection dialog
!echo {preset:[ECHO_TITLE1]} {content:MiniTermScriptExample.mts}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_include} {label:Example 'include'} {description:Include value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_cmdmultiline} {label:Example 'cmdmultiline'} {description:Command multiline value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_echo} {label:Example 'echo'} {description:Echo value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_echo_space} {label:Example 'echo_space'} {description:Echo space value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_echo_user_variables} {label:Example 'echo_user_variables'} {description:Echo user variables value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_echo_app_variables} {label:Example 'echo_app_variables'} {description:Echo application variables value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_echo_result} {label:Example 'echo_result'} {description:Result variables value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_setvariable} {label:Example 'setvariable'} {description:SetVariable value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_setvariable_const} {label:Example 'setvariable_const'} {description:SetVariable const value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_setvariable_error} {label:ERROR-Example 'setvariable_error'} {description:SetVariable error value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_msgbox} {label:Example 'msgbox'} {description:Messagebox value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_msgbox_custom} {label:Example 'msgbox_custom'} {description:Custom messagebox value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_userinput} {label:Example 'userinput'} {description:UserInput value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_userinput_controls} {label:Example 'userinput_controls'} {description:UserInput controls value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_wait} {label:Example 'wait'} {value:false} {description:Wait value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_stopwatch} {label:Example 'stopwatch'} {value:false} {description:Stop watch value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_ifthenelse} {label:Example 'ifthenelse'} {description:IfThenElse value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_ifthenelse_regex} {label:Example 'ifthenelse_regex'} {description:IfThenElseRegex value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_ifthenelse_contains} {label:Example 'ifthenelse_contains'} {description:IfThenElseContains value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_ifthenelse_loop} {label:Example 'ifthenelse_loop'} {description:IfThenElseLoop value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_switch} {label:Example 'switch'} {description:Switch value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_math} {label:Example 'calculate_math'} {description:Calculate math value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_logic} {label:Example 'calculate_logic'} {description:Calculate logic value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_iif} {label:Example 'calculate_iif'} {description:Calculate iif value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_round_sigdig} {label:Example 'calculate_round_sigdig'} {description:Calculate round sigdig value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_round_dec} {label:Example 'calculate_round_dec'} {description:Calculate round dec value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_calculate_absolute} {label:Example 'calculate_absolute'} {description:Calculate absolute value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_polynomialfit} {label:Example 'polynomial_fit'} {description:Polynomial fit value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_rs232} {label:Example 'rs232'} {description:RS232 value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_directoryexists} {label:Example 'directoryexists'} {description:Directory exists value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_directorycopy} {label:Example 'directorycopy'} {description:Directory copy value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_directorymove} {label:Example 'directorymove'} {description:Directory move value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_directorydelete} {label:Example 'directorydelete'} {description:Directory delete value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_directorycreate} {label:Example 'directorycreate'} {description:Directory create value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_fileexists} {label:Example 'fileexists'} {description:File exists value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_filecopy} {label:Example 'filecopy'} {description:File copy value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_filemove} {label:Example 'filemove'} {description:File move value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_filedelete} {label:Example 'filedelete'} {description:File delete value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_filewrite} {label:Example 'filewrite'} {description:File write value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_pdfwrite} {label:Example 'pdfwrite'} {description:PdfWrite value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_openurl} {label:Example 'openurl'} {description:Open url value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_runexecutable} {label:Example 'runexecutable'} {description:Run executable value}
!setvariable {preset:[SELECTION_CHECKBOX]} {name:_example_backgroundread} {label:Example 'backgroundread'} {description:BackgroundRead value}
!userinput {title:Example selection} {group:group_example_selection} {label:Example 'selection'} {showcollapseexpand:True} {showunselectselectall:True}
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Preprocess 'include'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_include]} {actiontrue:___BEGIN_EXAMPLE_INCLUDE} {actionfalse:___END_EXAMPLE_INCLUDE}
::___BEGIN_EXAMPLE_INCLUDE
!echo {preset:[ECHO_TITLE2]} {content:Preprocess 'include'}
/// Variable not possible --> Preprocess!
///!setvariable {name:_filepath} {value:.\MiniTermScriptExampleSub.mts} {group:group_example_include} {description:Relative or absolute file path}
///!userinput {title:Example 'include'} {group:group_example_include}
///#include [_filepath]
#include .\MiniTermScriptExampleSub.mts
!wait {secs:2}
::___END_EXAMPLE_INCLUDE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Preprocess 'Command multiline'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_cmdmultiline]} {actiontrue:___BEGIN_EXAMPLE_CMDMULTILINE} {actionfalse:___END_EXAMPLE_CMDMULTILINE}
::___BEGIN_EXAMPLE_CMDMULTILINE
!echo {preset:[ECHO_TITLE2]} {content:Preprocess 'Command multiline'}
!echo {foreground:Green}\   
    {fontweight:Bold}    \    
	{fontsize:11} \
	{content:Command auf mehrere Zeilen aufgeteilt}
!wait {secs:2}
::___END_EXAMPLE_CMDMULTILINE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'echo'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_echo]} {actiontrue:___BEGIN_EXAMPLE_ECHO} {actionfalse:___END_EXAMPLE_ECHO}
::___BEGIN_EXAMPLE_ECHO
!echo {preset:[ECHO_TITLE2]} {content:Command 'echo'}
!echo {content:A simple message}
!echo {foreground:Red} {content:foreground:Red}
!echo {fontstyle:Normal} {content:fontstyle:Normal}
!echo {foreground:Blue} {decoration:Strikethrough} {content:foreground:Blue | decoration:Strikethrough}
!echo {foreground:Green} {decoration:Underline} {content:foreground:Green | decoration:Underline}
!echo {foreground:Magenta} {fontweight:Bold} {fontsize:14} {fontfamily:Courier New} {content:foreground:Magenta | fontweight:Bold | fontsize:14 | fontfamily:Courier New}
!echo {foreground:Magenta} {fontweight:Bold} {fontsize:14} {fontfamily:Verdana} {content:foreground:Magenta | fontweight:Bold | fontsize:14 | fontfamily:Verdana}
!wait {secs:2}
::___END_EXAMPLE_ECHO
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'echo space'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_echo_space]} {actiontrue:___BEGIN_EXAMPLE_SPACE} {actionfalse:___END_EXAMPLE_SPACE}
::___BEGIN_EXAMPLE_SPACE
!echo {preset:[ECHO_TITLE2]} {content:Command 'echo space'}
!setvariable {name:_spacebefore} {value:24} {group:group_example_echo_space} {description:Space before size value} {extension:[size]}
!setvariable {name:_spaceafter} {value:18} {group:group_example_echo_space} {description:Space before size value} {extension:[size]}
!userinput {title:Example 'echo space'} {group:group_example_echo_space}
!echo {content:A text after space with size [_spacebefore]} {spacesizebefore:[_spacebefore]}
!echo {content:A text} {spacesizeafter:[_spaceafter]}
!echo {content:A text after space with size [_spaceafter]}
!wait {secs:2}
::___END_EXAMPLE_SPACE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'echo user variables'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_echo_user_variables]} {actiontrue:___BEGIN_EXAMPLE_ECHO_USER_VARIABLES} {actionfalse:___END_EXAMPLE_ECHO_USER_VARIABLES}
::___BEGIN_EXAMPLE_ECHO_USER_VARIABLES
!echo {preset:[ECHO_TITLE2]} {content:Command 'echo user variables'}
!setvariable {name:_uservalue} {value:hello world} {group:group_example_echo_user_variables} {description:User variable value} {extension:[anytext]}
!userinput {title:Example 'echo user variables'} {group:group_example_echo_user_variables}
!echo {content:User value: [_uservalue]}
!wait {secs:2}
::___END_EXAMPLE_ECHO_USER_VARIABLES
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'echo application variables'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_echo_app_variables]} {actiontrue:___BEGIN_EXAMPLE_ECHO_APP_VARIABLES} {actionfalse:___END_EXAMPLE_ECHO_APP_VARIABLES}
::___BEGIN_EXAMPLE_ECHO_APP_VARIABLES
!echo {preset:[ECHO_TITLE2]} {content:Command 'echo application variables'}
!echo {fontfamily:Courier New} {content:DateTimeFormat : [DATETIMEFORMAT] -> DateTime: [DATETIME]}
!echo {fontfamily:Courier New} {content:DateFormat     : [DATEFORMAT]          -> Date    : [DATE]}
!echo {fontfamily:Courier New} {content:TimeFormat     : [TIMEFORMAT]            -> Time    : [TIME]}
!setvariable {name:DATEFORMAT} {value:yyyy}
!setvariable {name:TIMEFORMAT} {value:HH}
!setvariable {name:DATETIMEFORMAT} {value:yyyy HH}
!echo {fontfamily:Courier New} {content:DateTimeFormat : [DATETIMEFORMAT] -> DateTime: [DATETIME]}
!echo {fontfamily:Courier New} {content:DateFormat     : [DATEFORMAT]    -> Date    : [DATE]}
!echo {fontfamily:Courier New} {content:TimeFormat     : [TIMEFORMAT]      -> Time    : [TIME]}
!echo {fontfamily:Courier New} {content:APPDIR         : [APPDIR]}
!echo {fontfamily:Courier New} {content:SCRIPTDIR      : [SCRIPTDIR]}
!echo {fontfamily:Courier New} {content:SCRIPTFILEPATH : [SCRIPTFILEPATH]}
!wait {secs:2}
::___END_EXAMPLE_ECHO_APP_VARIABLES
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'echo result'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_echo_result]} {actiontrue:___BEGIN_EXAMPLE_ECHO_RESULT} {actionfalse:___END_EXAMPLE_ECHO_RESULT}
::___BEGIN_EXAMPLE_ECHO_RESULT
!setvariable {name:_preset} {value:{foreground:Green}} {group:group_example_echo_result} {description:Preset variable value}
!setvariable {name:_filepath} {value:.\Data\ScriptResults.srt} {group:group_example_echo_result} {description:Output file variable value}
!setvariable {name:_script} {value:ScriptXYZ} {group:group_example_echo_result} {description:Script variable value}
!setvariable {name:_scriptversion} {value:V1-0-0} {group:group_example_echo_result} {description:Script version variable value}
!setvariable {name:_components} {value:Comp1|V1-0-0;Comp2|V2-0-0;Comp3|V3-0-0} {group:group_example_echo_result} {description:Components variable value}
!setvariable {name:_tester} {value:Hans Tester} {group:group_example_echo_result} {description:Tester variable value}
!setvariable {name:_testname} {value:Test1} {group:group_example_echo_result} {description:Testname variable value}
!setvariable {name:_testid} {value:1} {group:group_example_echo_result} {description:Testid variable value}
!setvariable {name:_testdescription} {value:A description...} {group:group_example_echo_result} {description:Testdescription variable value}
!setvariable {name:_uut} {value:CV180 20-0001} {group:group_example_echo_result} {description:UUT variable value}
!setvariable {name:_expectedresult} {value:Temperature1|17.3|°C;Temperature2|22.5|°C} {group:group_example_echo_result} {description:Expected result variable value}
!setvariable {name:_testresult} {value:17.3;22.5} {group:group_example_echo_result} {description:Testresult variable value}
///!setvariable {name:_teststatus} {value:PASS} {group:group_example_echo_result} {description:Teststatus variable value}
!setvariable {name:_teststatus} {value:PASS} {group:group_example_echo_result} {description:Teststatus variable value} {control:ComboBox} {valueoptions:PASS;FAIL;Not performed}
!setvariable {name:_testconditions} {value:Rainy} {group:group_example_echo_result} {description:Testconditions variable value}
!setvariable {name:_testtimestamp} {value:2020-03-24 17:51} {group:group_example_echo_result} {description:Testtimestamp variable value}
!setvariable {name:_testduration} {value:2.5} {group:group_example_echo_result} {description:Testduration variable value}
///!setvariable {name:_testdurationunit} {value:s} {group:group_example_echo_result} {description:Testdurationunit variable value}
!setvariable {name:_testdurationunit} {value:Seconds} {group:group_example_echo_result} {description:DurationUnit variable value} {control:ComboBox} {valueoptions:Milliseconds;Seconds;Minutes;Hours;Days}
!setvariable {name:_remarks} {value:Additional information...} {group:group_example_echo_result} {description:Testdurationunit variable value}
!userinput {title:Example 'echo result variables'} {group:group_example_echo_result}
!echo {preset:[_preset]} {filepath:[_filepath]} {script:[_script]} {scriptversion:[_scriptversion]} {components:[_components]} {testname:[_testname]} {testid:[_testid]} {testdescription:[_testdescription]} {uut:[_uut]} {expectedresult:[_expectedresult]} {testresult:[_testresult]} {teststatus:[_teststatus]} {testconditions:[_testconditions]} {testtimestamp:[_testtimestamp]} {testduration:[_testduration]}  {testdurationunit:[_testdurationunit]} {tester:[_tester]} {remarks:[_remarks]}
!wait {secs:2}
::___END_EXAMPLE_ECHO_RESULT
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'setvariable'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_setvariable]} {actiontrue:___BEGIN_EXAMPLE_SETVARIABLE} {actionfalse:___END_EXAMPLE_SETVARIABLE}
::___BEGIN_EXAMPLE_SETVARIABLE
!echo {preset:[ECHO_TITLE2]} {content:Command 'setvariable'}
!setvariable {name:_variable} {label:Variable} {value:anything} {group:group_example_setvariable} {description:Variable (any type)}
!userinput {title:Example 'setvariable'} {group:group_example_setvariable}
!echo {content:Variable: [_variable]}
!wait {secs:2}
::___END_EXAMPLE_SETVARIABLE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'setvariable const'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_setvariable_const]} {actiontrue:___BEGIN_EXAMPLE_SETVARIABLE_CONST} {actionfalse:___END_EXAMPLE_SETVARIABLE_CONST}
::___BEGIN_EXAMPLE_SETVARIABLE_CONST
!echo {preset:[ECHO_TITLE2]} {content:Command 'setvariable const'}
!echo {content:Time example}
!setvariable {name:timedyn} {value:[TIME]}
!setvariable {name:timeconst} {value:[TIME]} {const:True}
!echo {content:timedyn -> [timedyn]} {debug:True}
!echo {content:timeconst -> [timeconst]} {debug:True}
!wait {secs:2}
!echo {content:timedyn -> [timedyn]} {debug:True}
!echo {content:timeconst -> [timeconst]} {debug:True}
!echo {content:}
!echo {content:Loop example}
!setvariable {name:X_SET_PT_1}{value:40}
!setvariable {name:X_SET_PT_2}{value:100}
!setvariable {name:counter}{value:0}
!setvariable {name:numberOfSetPoints}{value:3}
::___EXAMPLE_SETVARIABLE_CONST_START_LOOP
!calculate        {expression:[counter]+1}{variable:counter}
!echo            {content:Loop-Nr. [counter]}
!setvariable    {name:_set_pt}{value:[X_SET_PT_[counter]]}
!echo            {content:Set-Pt (debug): [_set_pt]} {debug:True}
!echo            {content:Set-Pt: [_set_pt]}
!ifthenelse        {expression:[counter]<[numberOfSetPoints]} {actionfalse:___EXAMPLE_SETVARIABLE_CONST_END_LOOP} {actiontrue:___EXAMPLE_SETVARIABLE_CONST_START_LOOP}
::___EXAMPLE_SETVARIABLE_CONST_END_LOOP

!wait {secs:2}
::___END_EXAMPLE_SETVARIABLE_CONST
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'setvariable error'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_setvariable_error]} {actiontrue:___BEGIN_EXAMPLE_SETVARIABLE_ERROR} {actionfalse:___END_EXAMPLE_SETVARIABLE_ERROR}
::___BEGIN_EXAMPLE_SETVARIABLE_ERROR
!echo {preset:[ECHO_TITLE2]} {content:Erroneous command 'setvariable'}
!setvariable {name:_v1} {value:[_v1]} {group:group_example_setvariable_error}
!echo {content:_v1 -> [_v1]} {debug:False}
!setvariable {name:_v10} {value:[_v20]} {group:group_example_setvariable_error}
!setvariable {name:_v20} {value:[_v10]} {group:group_example_setvariable_error}
!setvariable {name:_v30} {value:[_v10]-[_v20]} {group:group_example_setvariable_error}
!echo {content:_v10 -> [_v10]} {debug:False}
!echo {content:_v20 -> [_v20]} {debug:False}
!echo {content:_v30 -> [_v30]} {debug:False}
!wait {secs:2}
::___END_EXAMPLE_SETVARIABLE_ERROR
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'messagebox'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_msgbox]} {actiontrue:___BEGIN_EXAMPLE_MSGBOX} {actionfalse:___END_EXAMPLE_MSGBOX}
::___BEGIN_EXAMPLE_MSGBOX
!echo {preset:[ECHO_TITLE2]} {content:Command 'messagebox'}
!setvariable {name:_msgboxYesNoCancel} {value:-} {group:msgboxinput} {description:MessageboxYesNoCancel value}
!setvariable {name:_msgboxOKCancel} {value:-} {group:msgboxinput} {description:MessageboxOKCancel value}
!messagebox {title:Messagebox YesNoCancel} {content:1) Text1\r\n2) Text2\r\n\r\nPlease select a button...} {button:YesNoCancel} {image:Question} {defaultresult:Yes} {variable:_msgboxYesNoCancel}
!messagebox {title:Messagebox OKCancel} {content:Please select a button...} {button:OKCancel} {image:Question} {defaultresult:OK} {variable:_msgboxOKCancel}
!echo {content:Messagebox 'YesNoCancel' result: [_msgboxYesNoCancel]}
!echo {content:Messagebox 'OKCancel' result: [_msgboxOKCancel]}
!wait {secs:2}
::___END_EXAMPLE_MSGBOX
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'messagebox_custom'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_msgbox_custom]} {actiontrue:___BEGIN_EXAMPLE_MSGBOX_CUSTOM} {actionfalse:___END_EXAMPLE_MSGBOX_CUSTOM}
::___BEGIN_EXAMPLE_MSGBOX_CUSTOM
!echo {preset:[ECHO_TITLE2]} {content:Command 'messagebox_custom'}
!setvariable {name:_lines} {value:Daredevil|.\Images\daredevil.jpg|150||Text1\r\n1) aaa\r\n2) bbb\r\n3) ccc;Jessica Jones|.\Images\jessicajones.jpg|200||Text2\r\n1) xxx\r\n2) yyy\r\n3) zzz} {group:group_example_msgboxcustom} {description:Custommessagebox value}
!setvariable {name:_buttonleft} {value:} {group:group_example_msgboxcustom} {description:Left button value}
!setvariable {name:_buttonmiddle} {value:Hello;ResultHello} {group:group_example_msgboxcustom} {description:Middle button value}
!setvariable {name:_buttonright} {value:World;ResultWorld;Default} {group:group_example_msgboxcustom} {description:Rigth button value}
!setvariable {name:_result} {value:-} {group:group_example_msgboxcustom} {description:Result value}
!userinput {title:Example 'messagebox custom'} {group:group_example_msgboxcustom}
!custommessagebox {text:[_lines]} {variable:_result} {buttonleft:[_buttonleft]} {buttonmiddle:[_buttonmiddle]} {buttonright:[_buttonright]}
!echo {content:Custommessagebox result: [_result]}
!wait {secs:2}
::___END_EXAMPLE_MSGBOX_CUSTOM
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'userinput'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_userinput]} {actiontrue:___BEGIN_EXAMPLE_USERINPUT} {actionfalse:___END_EXAMPLE_USERINPUT}
::___BEGIN_EXAMPLE_USERINPUT
!echo {preset:[ECHO_TITLE2]} {content:Command 'userinput'}
!setvariable {name:_entry1} {value:hello} {group:group_example_userinput} {description:Entry1 value}
!setvariable {name:_entry2} {value:world} {group:group_example_userinput} {description:Entry2 value}
!userinput {title:Example 'userinput'} {group:group_example_userinput}
!echo {content:Entry1: [_entry1]}
!echo {content:Entry2: [_entry2]}
!wait {secs:2}
::___END_EXAMPLE_USERINPUT
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'userinput controls'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_userinput_controls]} {actiontrue:___BEGIN_EXAMPLE_USERINPUT_CONTROLS} {actionfalse:___END_EXAMPLE_USERINPUT_CONTROLS}
::___BEGIN_EXAMPLE_USERINPUT_CONTROLS
!echo {preset:[ECHO_TITLE2]} {content:Command 'userinput controls'}
!setvariable {name:_string} {value:hello world} {group:group_example_userinput_controls} {description:String value}
!setvariable {name:_bool} {value:true} {group:group_example_userinput_controls} {description:Bool value} {control:CheckBox}
!setvariable {name:_option} {value:1} {group:group_example_userinput_controls} {description:Options value} {extension:mA} {control:ComboBox} {valueoptions:1;1.5;2}
!userinput {title:Example 'userinput controls'} {group:group_example_userinput_controls}
!echo {content:String: [_string]}
!echo {content:Bool: [_bool]}
!echo {content:option: [_option]}
!wait {secs:2}
::___END_EXAMPLE_USERINPUT_CONTROLS
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'wait'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_wait]} {actiontrue:___BEGIN_EXAMPLE_WAIT} {actionfalse:___END_EXAMPLE_WAIT}
::___BEGIN_EXAMPLE_WAIT
!echo {preset:[ECHO_TITLE2]} {content:Command 'wait'}
!wait {msecs:500}
!echo {content:...after 500ms}
!wait {secs:5}
!echo {content:...after 5s or skipped}
!setvariable {name:_wait_ms} {value:2000} {group:group_example_wait} {description:Wait in ms value}
!userinput {title:Example wait} {group:group_example_wait}
!setvariable {name:_timeelapsedin} {value:0} {group:group_example_wait} {description:Wait in ms value}
!wait {msecs:[_wait_ms]} {timeelapsedinsec:_timeelapsed} {actionfinished:___WAIT_FINISHED} {actionskipped:___WAIT_SKIPPED}
::___WAIT_SKIPPED
!echo {content:...after [_timeelapsed] s (skipped)}
!goto ___WAIT_END
::___WAIT_FINISHED
!echo {content:...after [_timeelapsed] s}
::___WAIT_END
!wait {secs:2}
::___END_EXAMPLE_WAIT
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'stopwatch'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_stopwatch]} {actiontrue:___BEGIN_EXAMPLE_STOPWATCH} {actionfalse:___END_EXAMPLE_STOPWATCH}
::___BEGIN_EXAMPLE_STOPWATCH
!echo {preset:[ECHO_TITLE2]} {content:Command 'stopwatch'}
!setvariable {name:_stopwatch} {value:0} {group:group_example_stopwatch} {description:Stop watch value}
!userinput {title:Example stopwatch} {group:group_example_stopwatch}
!stopwatch {variable:_stopwatch}
!echo {content:_stopwatch: [_stopwatch]}
!wait {msecs:300}
!stopwatch {variable:_stopwatch}
!echo {content:_stopwatch: [_stopwatch]}
!wait {msecs:500}
!stopwatch {variable:_stopwatch}
!echo {content:_stopwatch: [_stopwatch]}
!wait {secs:2}
::___END_EXAMPLE_STOPWATCH
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'ifthenelse'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_ifthenelse]} {actiontrue:___BEGIN_EXAMPLE_IFTHENELSE} {actionfalse:___END_EXAMPLE_IFTHENELSE}
::___BEGIN_EXAMPLE_IFTHENELSE
!echo {preset:[ECHO_TITLE2]} {content:Command 'ifthenelse'}
!setvariable {name:_boolvalue1} {value:true} {group:group_example_ifthenelse} {default:true} {description:Boolean value1} {extension:[true/false]} {readonly:false}
!setvariable {name:_boolvalue2} {value:true} {group:group_example_ifthenelse} {default:true} {description:Boolean value2} {extension:[true/false]} {readonly:false}
!setvariable {name:_doublevalue1} {value:1.5} {group:group_example_ifthenelse} {default:1.0} {description:Double value1} {readonly:false}
!setvariable {name:_doublevalue2} {value:2.5} {group:group_example_ifthenelse} {default:2.0} {description:Double value2} {readonly:false}
!setvariable {name:_formula} {value:[_boolvalue1] AND [_boolvalue2]} {group:group_example_ifthenelse} {default:true} {description:Formula} {readonly:false}
!userinput {title:Example 'ifthenelse'} {group:group_example_ifthenelse}
!ifthenelse {expression:[_formula]} {actiontrue:___IF_TRUE} {actionfalse:___IF_FALSE} {actionexception:___IF_EXCEPTION}
::___IF_TRUE
!echo {content:Formula result: TRUE}
!goto ___IF_END
::___IF_FALSE
!echo {content:Formula result: FALSE}
!goto ___IF_END
::___IF_EXCEPTION
!echo {content:Formula result: EXCEPTION}
::___IF_END
!wait {secs:2}
::___END_EXAMPLE_IFTHENELSE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'ifthenelse regex'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_ifthenelse_regex]} {actiontrue:___BEGIN_EXAMPLE_IFTHENELSE_REGEX} {actionfalse:___END_EXAMPLE_IFTHENELSE_REGEX}
::___BEGIN_EXAMPLE_IFTHENELSE_REGEX
!echo {preset:[ECHO_TITLE2]} {content:Command 'ifthenelse regex'}
!setvariable {name:_regexpattern} {value:.*EIN.*} {group:group_example_ifthenelse_regex} {description:Regex pattern} {readonly:false}
!setvariable {name:_regexvalue} {value:das ist EIN text} {group:group_example_ifthenelse_regex} {default:1.0} {description:Regex value} {readonly:false}
!userinput {title:Example 'ifthenelse regex'} {group:group_example_ifthenelse_regex}
!ifthenelse {regexpattern:[_regexpattern]} {regexvalue:[_regexvalue]} {actiontrue:___REGEX_IF_TRUE} {actionfalse:___REGEX_IF_FALSE}
::___REGEX_IF_TRUE
!echo {content:Regex result: TRUE}
!goto ___REGEX_IF_END
::___REGEX_IF_FALSE
!echo {content:Regex result: FALSE}
::___REGEX_IF_END
!wait {secs:2}
::___END_EXAMPLE_IFTHENELSE_REGEX
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'ifthenelse contains'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_ifthenelse_contains]} {actiontrue:___BEGIN_EXAMPLE_IFTHENELSE_CONTAINS} {actionfalse:___END_EXAMPLE_IFTHENELSE_CONTAINS}
::___BEGIN_EXAMPLE_IFTHENELSE_CONTAINS
!echo {preset:[ECHO_TITLE2]} {content:Command 'ifthenelse contains'}
!setvariable {name:_containstest} {value:abc} {group:group_example_ifthenelse_contains} {description:Contains group} {readonly:false}
!setvariable {name:_containsgroup} {value:group_example_ifthenelse_contains} {group:group_example_ifthenelse_contains} {description:Contains group} {readonly:false}
!setvariable {name:_containsmember} {value:_containstest} {group:group_example_ifthenelse_contains} {default:1.0} {description:Contains member} {readonly:false}
!userinput {title:Example 'ifthenelse contains'} {group:group_example_ifthenelse_contains}
!ifthenelse {containsgroup:[_containsgroup]} {containsmember:[_containsmember]} {actiontrue:___CONTAINS_IF_TRUE} {actionfalse:___CONTAINS_IF_FALSE}
::___CONTAINS_IF_TRUE
!echo {content:Contains result: TRUE}
!goto ___CONTAINS_IF_END
::___CONTAINS_IF_FALSE
!echo {content:Contains result: FALSE}
::___CONTAINS_IF_END
!wait {secs:2}
::___END_EXAMPLE_IFTHENELSE_CONTAINS
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'ifthenelse loop'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_ifthenelse_loop]} {actiontrue:___BEGIN_EXAMPLE_IFTHENELSE_LOOP} {actionfalse:___END_EXAMPLE_IFTHENELSE_LOOP}
::___BEGIN_EXAMPLE_IFTHENELSE_LOOP
!echo {preset:[ECHO_TITLE2]} {content:Command 'ifthenelse loop'}
!setvariable {name:_loopcounter} {value:0} {group:group_example_ifthenelse_loop} {description:Loop counter}
::___LOOP_START
!calculate {expression:[_loopcounter]+1} {variable:_loopcounter}
!echo {content:loopcounter=[_loopcounter]}
!wait {msecs:500}
!ifthenelse {expression:[_loopcounter]<4} {actiontrue:___LOOP_START}
!echo {content:Loop end}
!wait {secs:2}
::___END_EXAMPLE_IFTHENELSE_LOOP
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'switch'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_switch]} {actiontrue:___BEGIN_EXAMPLE_SWITCH} {actionfalse:___END_EXAMPLE_SWITCH}
::___BEGIN_EXAMPLE_SWITCH
!echo {preset:[ECHO_TITLE2]} {content:Command 'switch'}
!setvariable {name:_value} {value:hello world} {group:group_example_switch} {description:A value}
!setvariable {name:_cases} {value:{regex;^hello.*;___SWITCH_1} {regex;.*world;___SWITCH_2} {expr;15;___SWITCH_3}} {group:group_example_switch} {description:Cases}
!userinput {title:Example 'switch'} {group:group_example_switch}
!switch {value:[_value]} {cases:[_cases]}
!echo {content:Default}
!goto ___SWITCH_END
::___SWITCH_1
!echo {content:Switch1}
!goto ___SWITCH_END
::___SWITCH_2
!echo {content:Switch2}
!goto ___SWITCH_END
::___SWITCH_3
!echo {content:Switch3}
::___SWITCH_END
!wait {secs:2}
::___END_EXAMPLE_SWITCH
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate math'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_math]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_MATH} {actionfalse:___END_EXAMPLE_CALCULATE_MATH}
::___BEGIN_EXAMPLE_CALCULATE_MATH
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate math'}
!setvariable {name:_value1} {value:5.6} {group:group_example_calculate_math} {description:Value1}
!setvariable {name:_value2} {value:10.4} {group:group_example_calculate_math} {description:Value2 value}
!setvariable {name:_formula} {value:100/([_value1]-[_value2])} {group:group_example_calculate_math} {description:Formula value}
!userinput {title:Example 'calculate math'} {group:group_example_calculate_math}
!calculate {expression:[_formula]} {variable:_calculateresult} {defaultresult:Ein Fehler ist aufgetreten}
!echo {content:_calculateresult=[_calculateresult]}
!wait {secs:2}
::___END_EXAMPLE_CALCULATE_MATH
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate logic'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_logic]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_LOGIC} {actionfalse:___END_EXAMPLE_CALCULATE_LOGIC}
::___BEGIN_EXAMPLE_CALCULATE_LOGIC
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate logic'}
!setvariable {name:_value1} {value:true} {group:group_example_calculate_logic} {description:Value1}
!setvariable {name:_value2} {value:false} {group:group_example_calculate}_logic {description:Value2 value}
!setvariable {name:_formula} {value:[_value1] AND [_value2]} {group:group_example_calculate_logic} {description:Formula value}
!userinput {title:Example 'calculate logic'} {group:group_example_calculate_logic}
!calculate {expression:[_formula]} {variable:_calculateresult}
!echo {content:_calculateresult=[_calculateresult]}

!wait {secs:2}
::___END_EXAMPLE_CALCULATE_LOGIC
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate iif'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_iif]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_IIF} {actionfalse:___END_EXAMPLE_CALCULATE_IIF}
::___BEGIN_EXAMPLE_CALCULATE_IIF
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate iif'}
!setvariable {name:_price} {value:500} {group:group_example_calculate_iif} {description:Price}
!setvariable {name:_pricelimit} {value:1000} {group:group_example_calculate_iif} {description:Price limit}
!setvariable {name:_result1} {value:expensive} {group:group_example_calculate_iif} {description:Result1}
!setvariable {name:_result2} {value:cheap} {group:group_example_calculate_iif} {description:Result2}
!setvariable {name:_formula} {value:IIF([_price]>=[_pricelimit]} {group:group_example_calculate_iif} {description:Formula value}
!userinput {title:Example 'calculate iif'} {group:group_example_calculate_iif}
!calculate {expression:IIF([_price]>=[_pricelimit], '[_result1]', '[_result2]')} {variable:_calcresult}
!echo {content:_calcresult=[_calcresult]}

!wait {secs:2}
::___END_EXAMPLE_CALCULATE_IIF
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate round sigdig'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_round_sigdig]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_ROUND_SIGDIG} {actionfalse:___END_EXAMPLE_CALCULATE_ROUND_SIGDIG}
::___BEGIN_EXAMPLE_CALCULATE_ROUND_SIGDIG
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate round sigdig'}
!setvariable {name:_value} {value:1.23456} {group:group_example_calculate_round_sigdig} {description:Value}
!setvariable {name:_calcresult} {value:[_value]} {group:group_example_calculate_round_sigdig} {description:Result}
!setvariable {name:_formula} {value:ROUND([_value],4,SigDig)} {group:group_example_calculate_round_sigdig} {description:Formula value}
!userinput {title:Example 'calculate round sigdig'} {group:group_example_calculate_round_sigdig}
!calculate {expression:[_formula]} {variable:_calcresult}
!echo {content:_calcresult=[_calcresult]}

!wait {secs:2}
::___END_EXAMPLE_CALCULATE_ROUND_SIGDIG
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate round dec'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_round_dec]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_ROUND_DEC} {actionfalse:___END_EXAMPLE_CALCULATE_ROUND_DEC}
::___BEGIN_EXAMPLE_CALCULATE_ROUND_DEC
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate round dec'}
!setvariable {name:_value} {value:1.23456} {group:group_example_calculate_round_dec} {description:Value}
!setvariable {name:_calcresult} {value:[_value]} {group:group_example_calculate_round_dec} {description:Result}
!setvariable {name:_formula} {value:ROUND([_value],4,Dec)} {group:group_example_calculate_round_dec} {description:Formula value}
!userinput {title:Example 'calculate round dec'} {group:group_example_calculate_round_dec}
!calculate {expression:[_formula]} {variable:_calcresult}
!echo {content:_calcresult=[_calcresult]}

!wait {secs:2}
::___END_EXAMPLE_CALCULATE_ROUND_DEC
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'calculate absolute'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_calculate_absolute]} {actiontrue:___BEGIN_EXAMPLE_CALCULATE_ABSOLUTE} {actionfalse:___END_EXAMPLE_CALCULATE_ABSOLUTE}
::___BEGIN_EXAMPLE_CALCULATE_ABSOLUTE
!echo {preset:[ECHO_TITLE2]} {content:Command 'calculate absolute'}
!setvariable {name:_value} {value:1.23456} {group:group_example_calculate_absolute} {description:Value}
!setvariable {name:_calcresult} {value:[_value]} {group:group_example_calculate_absolute} {description:Result}
!setvariable {name:_formula} {value:ABSOLUTE([_value])} {group:group_example_calculate_absolute} {description:Formula value}
!userinput {title:Example 'calculate absolute'} {group:group_example_calculate_absolute}
!calculate {expression:[_formula]} {variable:_calcresult}
!echo {content:_calcresult=[_calcresult]}

!wait {secs:2}
::___END_EXAMPLE_CALCULATE_ABSOLUTE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example: 'polynomialfit'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_polynomialfit]} {actiontrue:___BEGIN_EXAMPLE_POLYNOMIALFIT} {actionfalse:___END_EXAMPLE_POLYNOMIALFIT}
::___BEGIN_EXAMPLE_POLYNOMIALFIT
!echo {preset:[ECHO_TITLE2]} {content:Command 'polynomialfit'}
!setvariable {name:_csvfilepath} {value:.\Data\20-0303.txt} {group:group_example_polynomialfit} {description:CSV file path}
!setvariable {name:_xcolumn} {value:20-0303 DCHeaterNTC} {group:group_example_polynomialfit} {description:Data column x}
!setvariable {name:_ycolumn} {value:20-0303 LED1Current} {group:group_example_polynomialfit} {description:Data column y}
!setvariable {name:_delimiter} {value:;} {group:group_example_polynomialfit} {description:Data column delimiter}
!setvariable {name:_polyorder} {value:2} {group:group_example_polynomialfit} {description:Polynomial order}
!setvariable {name:_rsquared} {value:-} {group:group_example_polynomialfit} {description:Coefficient 0}
!setvariable {name:_coeff0} {value:-} {group:group_example_polynomialfit} {description:Coefficient 0}
!setvariable {name:_coeff1} {value:-} {group:group_example_polynomialfit} {description:Coefficient 1}
!setvariable {name:_coeff2} {value:-} {group:group_example_polynomialfit} {description:Coefficient 1}
!setvariable {name:_coeff3} {value:-} {group:group_example_polynomialfit} {description:Coefficient 1}
!setvariable {name:_variables} {value:_rsquared;_coeff0;_coeff1;_coeff2;_coeff3} {group:group_example_polynomialfit} {description:Variables}
!userinput {title:Example 'polynomialfit'} {group:group_example_polynomialfit}
!polynomialfit {csvfilepath:[_csvfilepath]} {xcolumn:[_xcolumn]} {ycolumn:[_ycolumn]} {delimiter:[_delimiter]} {polyorder:[_polyorder]} {variable:[_variables]}
!echo {content:rsquared=[_rsquared]}
!echo {content:coeff0=[_coeff0]}
!echo {content:coeff1=[_coeff1]}
!echo {content:coeff2=[_coeff2]}
!echo {content:coeff3=[_coeff3]}

!wait {secs:2}
::___END_EXAMPLE_POLYNOMIALFIT
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'rs232'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_rs232]} {actiontrue:___BEGIN_EXAMPLE_RS232} {actionfalse:___END_EXAMPLE_RS232}
::___BEGIN_EXAMPLE_RS232
!echo {preset:[ECHO_TITLE2]} {content:Command 'rs232'}
!setvariable {name:_alias} {value:spx} {group:group_example_rs232} {description:Alias}
!setvariable {name:_comport} {value:COM2} {group:group_example_rs232} {description:Comport}
!setvariable {name:_baudrate} {value:9600} {group:group_example_rs232} {description:Baudrate}
!setvariable {name:_databits} {value:8} {group:group_example_rs232} {description:Databits}
!setvariable {name:_stopbits} {value:1} {group:group_example_rs232} {description:Stopbits}
!setvariable {name:_readtimeout} {value:500} {group:group_example_rs232} {extension:[ms]} {description:Read timeout}
!setvariable {name:_writetimeout} {value:500} {group:group_example_rs232} {extension:[ms]} {description:Write timeout}
!userinput {title:Example 'rs232'} {group:group_example_rs232}
!rs232 {alias:[_alias]} {comport:[_comport]} {baudrate:[_baudrate]} {databits:[_databits]} {stopbits:[_stopbits]} {readtimeout:[_readtimeout]} {writetimeout:[_writetimeout]}
!echo {content:RS232 opened}
!send {alias:[_alias]} {data:ein text\r\n}
!writeandread {alias:[_alias]} {data:sn?} {txtermination:\r\n} {rxtermination:\r\n} {variable:_rs232response}
!echo {content:RS232 response: [_rs232response]}
!wait {secs:2}
::___END_EXAMPLE_RS232
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'directoryexists'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_directoryexists]} {actiontrue:___BEGIN_EXAMPLE_DIRECTORYEXISTS} {actionfalse:___END_EXAMPLE_DIRECTORYEXISTS}
::___BEGIN_EXAMPLE_DIRECTORYEXISTS
!echo {preset:[ECHO_TITLE2]} {content:Command 'directoryexists'}
!setvariable {name:_directorypath} {value:.\Data\TestDirectory} {group:group_example_directoryexists} {description:Relative or absolute directory path}
!directoryexists {directorypath:[_directorypath]} {createifnotexistent:true}
!setvariable {name:_copytopath} {value:[_directorypath]_copy} {group:group_example_directoryexists} {description:Delete directory}
!setvariable {name:_deleteifexistent} {value:false} {group:group_example_directoryexists} {description:Delete directory} {control:CheckBox}
!setvariable {name:_createifnotexistent} {value:true} {group:group_example_directoryexists} {description:Create directory} {control:CheckBox}
!setvariable {name:_result} {value:false} {group:group_example_directoryexists} {description:Exists result} {control:CheckBox}
!setvariable {name:_actiontrue} {value:___EXAMPLE_DIRECTORYEXISTS_IFTRUE} {group:group_example_directoryexists} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_DIRECTORYEXISTS_IFFALSE} {group:group_example_directoryexists} {description:Action false}
!userinput {title:Example 'directoryexists'} {group:group_example_directoryexists}
!directoryexists {directorypath:[_directorypath]} {copytopath:[_copytopath]} {deleteifexistent:[_deleteifexistent]} {createifnotexistent:[_createifnotexistent]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:Directory [_directorypath] exists? [_result]}
!goto ___EXAMPLE_DIRECTORYEXISTS_IFEND
::___EXAMPLE_DIRECTORYEXISTS_IFTRUE
!echo {content:IFTRUE - Directory [_directorypath] exists? [_result]}
!goto ___EXAMPLE_DIRECTORYEXISTS_IFEND
::___EXAMPLE_DIRECTORYEXISTS_IFFALSE
!echo {content:IFFALSE - Directory [_directorypath] exists? [_result]}
::___EXAMPLE_DIRECTORYEXISTS_IFEND
!wait {secs:2}
::___END_EXAMPLE_DIRECTORYEXISTS
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'directorycopy'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_directorycopy]} {actiontrue:___BEGIN_EXAMPLE_DIRECTORYCOPY} {actionfalse:___END_EXAMPLE_DIRECTORYCOPY}
::___BEGIN_EXAMPLE_DIRECTORYCOPY
!echo {preset:[ECHO_TITLE2]} {content:Command 'directorycopy'}
!setvariable {name:_directorypath} {value:.\Data\TestDirectory} {group:group_example_directorycopy} {description:Relative or absolute directory path}
!directoryexists {directorypath:[_directorypath]} {createifnotexistent:true}
!setvariable {name:_copytopath} {value:[_directorypath]_copy} {group:group_example_directorycopy} {description:Relative or absolute directory path}
!setvariable {name:_actiontrue} {value:___EXAMPLE_DIRECTORYCOPY_IFTRUE} {group:group_example_directorycopy} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_DIRECTORYCOPY_IFFALSE} {group:group_example_directorycopy} {description:Action false}
!userinput {title:Example 'directorycopy'} {group:group_example_directorycopy}
!directorycopy {directorypath:[_directorypath]} {copytopath:[_copytopath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:Directory [_directorypath] copied? [_result]}
!goto ___EXAMPLE_DIRECTORYCOPY_IFEND
::___EXAMPLE_DIRECTORYCOPY_IFTRUE
!echo {content:IFTRUE - Directory [_directorypath] copied? [_result]}
!goto ___EXAMPLE_DIRECTORYCOPY_IFEND
::___EXAMPLE_DIRECTORYCOPY_IFFALSE
!echo {content:IFFALSE - Directory [_directorypath] copied? [_result]}
::___EXAMPLE_DIRECTORYCOPY_IFEND
!wait {secs:2}
::___END_EXAMPLE_DIRECTORYCOPY
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'directorymove'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_directorymove]} {actiontrue:___BEGIN_EXAMPLE_DIRECTORYMOVE} {actionfalse:___END_EXAMPLE_DIRECTORYMOVE}
::___BEGIN_EXAMPLE_DIRECTORYMOVE
!echo {preset:[ECHO_TITLE2]} {content:Command 'directorymove'}
!setvariable {name:_directorypath} {value:.\Data\TestDirectory} {group:group_example_directorymove} {description:Relative or absolute directory path}
!directoryexists {directorypath:[_directorypath]} {createifnotexistent:true}
!setvariable {name:_movetopath} {value:[_directorypath].move} {group:group_example_directorymove} {description:Relative or absolute directory path}
!setvariable {name:_actiontrue} {value:___EXAMPLE_DIRECTORYMOVE_IFTRUE} {group:group_example_directorymove} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_DIRECTORYMOVE_IFFALSE} {group:group_example_directorymove} {description:Action false}
!userinput {title:Example 'directorymove'} {group:group_example_directorymove}
!directorymove {directorypath:[_directorypath]} {movetopath:[_movetopath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:Directory [_directorypath] moved? [_result]}
!goto ___EXAMPLE_DIRECTORYMOVE_IFEND
::___EXAMPLE_DIRECTORYMOVE_IFTRUE
!echo {content:IFTRUE - Directory [_directorypath] moved? [_result]}
!goto ___EXAMPLE_DIRECTORYMOVE_IFEND
::___EXAMPLE_DIRECTORYMOVE_IFFALSE
!echo {content:IFFALSE - Directory [_directorypath] moved? [_result]}
::___EXAMPLE_DIRECTORYMOVE_IFEND
!wait {secs:2}
::___END_EXAMPLE_DIRECTORYMOVE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'directorydelete'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_directorydelete]} {actiontrue:___BEGIN_EXAMPLE_DIRECTORYDELETE} {actionfalse:___END_EXAMPLE_DIRECTORYDELETE}
::___BEGIN_EXAMPLE_DIRECTORYDELETE
!echo {preset:[ECHO_TITLE2]} {content:Command 'directorydelete'}
!setvariable {name:_directorypath} {value:.\Data\TestDirectory} {group:group_example_directorydelete} {description:Relative or absolute directory path}
!directoryexists {directorypath:[_directorypath]} {createifnotexistent:true}
!setvariable {name:_result} {value:false} {group:group_example_directorydelete} {description:Exists result} {control:CheckBox}
!setvariable {name:_actiontrue} {value:___EXAMPLE_DIRECTORYDELETE_IFTRUE} {group:group_example_directorydelete} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_DIRECTORYDELETE_IFFALSE} {group:group_example_directorydelete} {description:Action false}
!userinput {title:Example 'directorydelete'} {group:group_example_directorydelete}
!directorydelete {directorypath:[_directorypath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:Directory [_directorypath] deleted? [_result]}
!goto ___EXAMPLE_DIRECTORYDELETE_IFEND
::___EXAMPLE_DIRECTORYDELETE_IFTRUE
!echo {content:IFTRUE - Directory [_directorypath] deleted? [_result]}
!goto ___EXAMPLE_DIRECTORYDELETE_IFEND
::___EXAMPLE_DIRECTORYDELETE_IFFALSE
!echo {content:IFFALSE - Directory [_directorypath] deleted? [_result]}
::___EXAMPLE_DIRECTORYDELETE_IFEND
!wait {secs:2}
::___END_EXAMPLE_DIRECTORYDELETE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'directorycreate'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_directorycreate]} {actiontrue:___BEGIN_EXAMPLE_DIRECTORYCREATE} {actionfalse:___END_EXAMPLE_DIRECTORYCREATE}
::___BEGIN_EXAMPLE_DIRECTORYCREATE
!echo {preset:[ECHO_TITLE2]} {content:Command 'directorycreate'}
!setvariable {name:_directorypath} {value:.\Data\TestDirectory} {group:group_example_directorycreate} {description:Relative or absolute directory path}
!setvariable {name:_result} {value:false} {group:group_example_directorycreate} {description:Exists result} {control:CheckBox}
!setvariable {name:_actiontrue} {value:___EXAMPLE_DIRECTORYCREATE_IFTRUE} {group:group_example_directorycreate} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_DIRECTORYCREATE_IFFALSE} {group:group_example_directorycreate} {description:Action false}
!userinput {title:Example 'directorycreate'} {group:group_example_directorycreate}
!directorycreate {directorypath:[_directorypath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:Directory [_directorypath] created? [_result]}
!goto ___EXAMPLE_DIRECTORYCREATE_IFEND
::___EXAMPLE_DIRECTORYCREATE_IFTRUE
!echo {content:IFTRUE - Directory [_directorypath] created? [_result]}
!goto ___EXAMPLE_DIRECTORYCREATE_IFEND
::___EXAMPLE_DIRECTORYCREATE_IFFALSE
!echo {content:IFFALSE - Directory [_directorypath] created? [_result]}
::___EXAMPLE_DIRECTORYCREATE_IFEND
!wait {secs:2}
::___END_EXAMPLE_DIRECTORYCREATE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'fileexists'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_fileexists]} {actiontrue:___BEGIN_EXAMPLE_FILEEXISTS} {actionfalse:___END_EXAMPLE_FILEEXISTS}
::___BEGIN_EXAMPLE_FILEEXISTS
!echo {preset:[ECHO_TITLE2]} {content:Command 'fileexists'}
!setvariable {name:_filepath} {value:.\Data\TestFile.txt} {group:group_example_fileexists} {description:Relative or absolute file path}
!filewrite {filepath:[_filepath]} {content:Anything} {append:true}
!setvariable {name:_copytopath} {value:[_filepath].copy} {group:group_example_fileexists} {description:Relative or absolute file path}
!setvariable {name:_deleteifexistent} {value:false} {group:group_example_fileexists} {description:Delete file} {control:CheckBox}
!setvariable {name:_result} {value:false} {group:group_example_fileexists} {description:Exists result} {control:CheckBox}
!setvariable {name:_actiontrue} {value:___EXAMPLE_FILEEXISTS_IFTRUE} {group:group_example_fileexists} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_FILEEXISTS_IFFALSE} {group:group_example_fileexists} {description:Action false}
!userinput {title:Example 'fileexists'} {group:group_example_fileexists}
!fileexists {filepath:[_filepath]} {copytopath:[_copytopath]} {deleteifexistent:[_deleteifexistent]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:File [_filepath] exists? [_result]}
!goto ___EXAMPLE_FILEEXISTS_IFEND
::___EXAMPLE_FILEEXISTS_IFTRUE
!echo {content:IFTRUE - File [_filepath] exists? [_result]}
!goto ___EXAMPLE_FILEEXISTS_IFEND
::___EXAMPLE_FILEEXISTS_IFFALSE
!echo {content:IFFALSE - File [_filepath] exists? [_result]}
::___EXAMPLE_FILEEXISTS_IFEND
!wait {secs:2}
::___END_EXAMPLE_FILEEXISTS
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'filecopy'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_filecopy]} {actiontrue:___BEGIN_EXAMPLE_FILECOPY} {actionfalse:___END_EXAMPLE_FILECOPY}
::___BEGIN_EXAMPLE_FILECOPY
!echo {preset:[ECHO_TITLE2]} {content:Command 'filecopy'}
!setvariable {name:_filepath} {value:.\Data\TestFile.txt} {group:group_example_filecopy} {description:Relative or absolute file path}
!filewrite {filepath:[_filepath]} {content:Anything} {append:true}
!setvariable {name:_copytopath} {value:[_filepath].copy} {group:group_example_filecopy} {description:Relative or absolute file path}
!setvariable {name:_actiontrue} {value:___EXAMPLE_FILECOPY_IFTRUE} {group:group_example_filecopy} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_FILECOPY_IFFALSE} {group:group_example_filecopy} {description:Action false}
!userinput {title:Example 'filecopy'} {group:group_example_filecopy}
!filecopy {filepath:[_filepath]} {copytopath:[_copytopath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:File [_filepath] copied? [_result]}
!goto ___EXAMPLE_FILECOPY_IFEND
::___EXAMPLE_FILECOPY_IFTRUE
!echo {content:IFTRUE - File [_filepath] copied? [_result]}
!goto ___EXAMPLE_FILECOPY_IFEND
::___EXAMPLE_FILECOPY_IFFALSE
!echo {content:IFFALSE - File [_filepath] copied? [_result]}
::___EXAMPLE_FILECOPY_IFEND
!wait {secs:2}
::___END_EXAMPLE_FILECOPY
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'filemove'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_filemove]} {actiontrue:___BEGIN_EXAMPLE_FILEMOVE} {actionfalse:___END_EXAMPLE_FILEMOVE}
::___BEGIN_EXAMPLE_FILEMOVE
!echo {preset:[ECHO_TITLE2]} {content:Command 'filemove'}
!setvariable {name:_filepath} {value:.\Data\TestFile.txt} {group:group_example_filemove} {description:Relative or absolute file path}
!filewrite {filepath:[_filepath]} {content:Anything} {append:true}
!setvariable {name:_movetopath} {value:[_filepath].move} {group:group_example_filemove} {description:Relative or absolute file path}
!setvariable {name:_actiontrue} {value:___EXAMPLE_FILEMOVE_IFTRUE} {group:group_example_filemove} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_FILEMOVE_IFFALSE} {group:group_example_filemove} {description:Action false}
!userinput {title:Example 'filemove'} {group:group_example_filemove}
!filemove {filepath:[_filepath]} {movetopath:[_movetopath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:File [_filepath] moved? [_result]}
!goto ___EXAMPLE_FILEMOVE_IFEND
::___EXAMPLE_FILEMOVE_IFTRUE
!echo {content:IFTRUE - File [_filepath] moved? [_result]}
!goto ___EXAMPLE_FILEMOVE_IFEND
::___EXAMPLE_FILEMOVE_IFFALSE
!echo {content:IFFALSE - File [_filepath] moved? [_result]}
::___EXAMPLE_FILEMOVE_IFEND
!wait {secs:2}
::___END_EXAMPLE_FILEMOVE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'filedelete'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_filedelete]} {actiontrue:___BEGIN_EXAMPLE_FILEDELETE} {actionfalse:___END_EXAMPLE_FILEDELETE}
::___BEGIN_EXAMPLE_FILEDELETE
!echo {preset:[ECHO_TITLE2]} {content:Command 'filedelete'}
!setvariable {name:_filepath} {value:.\Data\TestFile.txt} {group:group_example_filedelete} {description:Relative or absolute file path}
!filewrite {filepath:[_filepath]} {content:Anything} {append:true}
!setvariable {name:_result} {value:false} {group:group_example_filedelete} {description:Exists result} {control:CheckBox}
!setvariable {name:_actiontrue} {value:___EXAMPLE_FILEDELETE_IFTRUE} {group:group_example_filedelete} {description:Action true}
!setvariable {name:_actionfalse} {value:___EXAMPLE_FILEDELETE_IFFALSE} {group:group_example_filedelete} {description:Action false}
!userinput {title:Example 'filedelete'} {group:group_example_filedelete}
!filedelete {filepath:[_filepath]} {variable:_result} {actiontrue:[_actiontrue]} {actionfalse:[_actionfalse]}
!echo {content:File [_filepath] deleted? [_result]}
!goto ___EXAMPLE_FILEDELETE_IFEND
::___EXAMPLE_FILEDELETE_IFTRUE
!echo {content:IFTRUE - File [_filepath] deleted? [_result]}
!goto ___EXAMPLE_FILEDELETE_IFEND
::___EXAMPLE_FILEDELETE_IFFALSE
!echo {content:IFFALSE - File [_filepath] deleted? [_result]}
::___EXAMPLE_FILEDELETE_IFEND
!wait {secs:2}
::___END_EXAMPLE_FILEDELETE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'filewrite'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_filewrite]} {actiontrue:___BEGIN_EXAMPLE_FILEWRITE} {actionfalse:___END_EXAMPLE_FILEWRITE}
::___BEGIN_EXAMPLE_FILEWRITE
!echo {preset:[ECHO_TITLE2]} {content:Command 'filewrite'}
!setvariable {name:_filepath} {value:.\Data\FileWrite.txt} {group:group_example_filewrite} {description:Relative or absolute file path}
!setvariable {name:_content} {value:This is a text} {group:group_example_filewrite} {description:Content}
!setvariable {name:_append} {value:true} {group:group_example_filewrite} {description:Content} {control:CheckBox}
!userinput {title:Example 'filewrite'} {group:group_example_filewrite}
!filewrite {filepath:[_filepath]} {content:[_content]} {append:[_append]}
!echo {content:File {_filepath} written}
!wait {secs:2}
::___END_EXAMPLE_FILEWRITE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'pdfwrite'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_pdfwrite]} {actiontrue:___BEGIN_EXAMPLE_PDFWRITE} {actionfalse:___END_EXAMPLE_PDFWRITE}
::___BEGIN_EXAMPLE_PDFWRITE
!echo {preset:[ECHO_TITLE2]} {content:Command 'pdfwrite'}
!setvariable {name:_filepath} {value:.\script.pdf} {group:group_example_pdfwrite} {description:Relative or absolute file path}
!userinput {title:Example 'pdfwrite'} {group:group_example_pdfwrite}
!pdfwrite {file:[_filepath]}
!echo {content:PDF written to [_filepath]}
!wait {secs:2}
::___END_EXAMPLE_PDFWRITE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'openurl'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_openurl]} {actiontrue:___BEGIN_EXAMPLE_OPENURL} {actionfalse:___END_EXAMPLE_OPENURL}
::___BEGIN_EXAMPLE_OPENURL
!echo {preset:[ECHO_TITLE2]} {content:Command 'openurl'}
!setvariable {name:_url} {value:www.mbw.ch} {group:group_example_openurl} {description:Url}
!userinput {title:Example 'openurl'} {group:group_example_openurl}
!openurl {url:[_url]}
!echo {content:Opened url [_url]}
!wait {secs:2}
::___END_EXAMPLE_OPENURL
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'runexecutable'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_runexecutable]} {actiontrue:___BEGIN_EXAMPLE_RUNEXECUTABLE} {actionfalse:___END_EXAMPLE_RUNEXECUTABLE}
::___BEGIN_EXAMPLE_RUNEXECUTABLE
!echo {preset:[ECHO_TITLE2]} {content:Command 'runexecutable'}
!setvariable {name:_executablepath} {value:notepad} {group:group_example_runexecutable} {description:Executable}
!setvariable {name:_arguments} {value:} {group:group_example_runexecutable} {description:Arguments}
!setvariable {name:_workingdirectory} {value:.\} {group:group_example_runexecutable} {description:Working directory}
!setvariable {name:_hidden} {value:False} {group:group_example_runexecutable} {description:Hidden window}
!userinput {title:Example 'runexecutable'} {group:group_example_runexecutable}
!runexecutable {executablepath:[_executablepath]} {arguments:[_arguments]} {workingdirectory:[_workingdirectory]} {hidden:[_hidden]}
!echo {content:Opened executable [_executablepath]}
!wait {secs:2}
::___END_EXAMPLE_RUNEXECUTABLE
/// endregion
/// --------------------------------------------------------------------------------

/// --------------------------------------------------------------------------------
/// region Example 'backgroundread'
/// --------------------------------------------------------------------------------
!ifthenelse {expression:[_example_backgroundread]} {actiontrue:___BEGIN_EXAMPLE_BACKGROUNDREAD} {actionfalse:___END_EXAMPLE_BACKGROUNDREAD}
::___BEGIN_EXAMPLE_BACKGROUNDREAD
!echo {preset:[ECHO_TITLE2]} {content:Command 'backgroundread'}

!setvariable {name:_alias} {value:spx} {group:group_example_backgroundread} {description:Alias}
!setvariable {name:_comport} {value:COM2} {group:group_example_backgroundread} {description:Comport}
!setvariable {name:_baudrate} {value:9600} {group:group_example_backgroundread} {description:Baudrate}
!setvariable {name:_databits} {value:8} {group:group_example_backgroundread} {description:Databits}
!setvariable {name:_stopbits} {value:1} {group:group_example_backgroundread} {description:Stopbits}
!setvariable {name:_readtimeout} {value:500} {group:group_example_backgroundread} {extension:[ms]} {description:Read timeout}
!setvariable {name:_writetimeout} {value:500} {group:group_example_backgroundread} {extension:[ms]} {description:Write timeout}
///!setvariable {name:_workeralias} {value:worker1} {group:group_example_backgroundread} {description:Alias}
!setvariable {name:_filepath} {value:.\read.txt} {group:group_example_backgroundread} {description:Relative or absolute file path}
!setvariable {name:_channels} {value:[_alias]|id?;[_alias]|sn?;[_alias]|dp?|double;[_alias]|fp?|double} {group:group_example_backgroundread} {description:Channels to read}
!setvariable {name:_intervalinsecs} {value:1.5} {group:group_example_backgroundread} {description:Loop interval in seconds}
!userinput {title:Example 'backgroundread'} {group:group_example_backgroundread}
!rs232 {alias:[_alias]} {comport:[_comport]} {baudrate:[_baudrate]} {databits:[_databits]} {stopbits:[_stopbits]} {readtimeout:[_readtimeout]} {writetimeout:[_writetimeout]}
!backgroundread {alias:[_backgroundalias]} {file:[_filepath]} {channels:[_channels]} {intervalinsecs:[_intervalinsecs]}
!wait {secs:10}
!backgroundread {alias:[_backgroundalias]} {stop:true}
!echo {content:BackgroundRead will be written to [_filepath] while script is running}
!wait {secs:10}
::___END_EXAMPLE_BACKGROUNDREAD

!goto ___EOF
/// endregion
/// --------------------------------------------------------------------------------


/// --------------------------------------------------------------------------------
/// region Deprecated
/// --------------------------------------------------------------------------------

/// Code
sn?
id?
dp?
fp?
control=1
control?
/// Code with options
sn? {validation:473-0000} {txrxwaitms:10} {continue:1}
sn? {validation:473-0000} {txrxwaitms:5000} {continue:1}
sn? {validation:abc} {continue:1}
sn? {validation:def} {continue:1}

fp? {variable:_fp}
!echo {content:_fp=[_fp]}
dp? {variable:_dp}
!echo {content:_dp=[_dp]}

/// Logging commands
!echo {content:This line is written as information to the log dialog}
!addtoreport This line is written as comment into the report file

/// Workflow
!wait {secs:2}

/// Settings commands
!parameter Size 200 !
!parameter WriteToLogInS 10
!parameter ReadFromInstrumentInS 1
!parameter ReadTimeLimitInS 15

/// --- 
!echo {content:Validation: tm < 0}
tm? {validation<:0} {continue:1}
!echo {content:Validation: tm < 1}
tm? {validation<:1} {continue:1}
!echo {content:Validation: tm < 2}
tm? {validation<:2} {continue:1}
!echo {content:Validation: tm <= 0}
tm? {validation<=:0} {continue:1}
!echo {content:Validation: tm <= 1}
tm? {validation<=:1} {continue:1}
!echo {content:Validation: tm <= 2}
tm? {validation<=:2} {continue:1}
!echo {content:Validation: tm = 0}
tm? {validation=:0} {continue:1}
!echo {content:Validation: tm = 1}
tm? {validation=:1} {continue:1}
!echo {content:Validation: tm = 2}
tm? {validation=:2} {continue:1}
!echo {content:Validation: tm >= 0}
tm? {validation>=:0} {continue:1}
!echo {content:Validation: tm >= 1}
tm? {validation>=:1} {continue:1}
!echo {content:Validation: tm >= 2}
tm? {validation>=:2} {continue:1}
!echo {content:Validation: tm > 0}
tm? {validation>:0} {continue:1}
!echo {content:Validation: tm > 1}
tm? {validation>:1} {continue:1}
!echo {content:Validation: tm > 2}
tm? {validation>:2} {continue:1}

::___A_Label
!wait {secs:2}
!goto ___A_Label

!echo {content:******************************************************************************}
!echo {content:END                    MiniTermScriptExample.mts                           END}
!echo {content:******************************************************************************}
/// endregion
/// --------------------------------------------------------------------------------


::___EOF
